# isoPy

Isopy is a Python 3 library for data processing in isotope geo/cosmochemistry.

## Installation

```bash
pip install isopy
```

**Note** Isopy requires python 3.9 and above.

For more information on installing isopy see Installing isopy documentation.

## Examples

Examples are avaliable here.

## License
[MIT]()

